@@ -78,6 +78,9 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
         for i in files:
             print("i... GLOBBED FILE=",i)
             main(i)
+        sys.exit(0)
+
+
     stor=Store.split(',')   # stor list = 0,1,2,3,4,5
     print("D... ####",stor)
 
@@ -201,9 +204,15 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
 
         #print("D.... parse ZIP", file=sys.stderr)
         #============================================= PLOT LOOP ==========START
+        # do here, later it wouldbe mess
+        xdivkov = 1
+        xunit = "um"
+
         for df,dfname in zip(seznam,seznamname):
+            print("____________", dfname[:80])
             print("D...  ******:", dfname    )
             print("D... ", df    )
+            #print(df, len(df))
             # print( "DFNAME  inx=",  inx, "  seznam[inx]=",seznam[inx]  , file=sys.stderr )
             # dfname=sorted(pd_file.keys())[ int(seznam[inx]) ]
 
@@ -214,28 +223,43 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
             # df=pd_file[dfname]
             # #==================
             # # here i can do fit?
+            # =============================== DECIDE ON WHAT IS THERE
             IMPLANT=False
             PASSTHROUGH=False
-
-            if  'e' in df.keys():
+            # i can have combined dfs ---------------------
+            #e=df[ df['e'].notnull() ]['e'] #
+            #x=df[ df['x'].notnull() ]['x'] # always nonnull
+            if  'e' in df.keys() and len( df[ df['e'].notnull() ]['e']  ) > 0: # e is always there?
+                #print("$$$ PASS", len(e))
                 e=df[ df['e'].notnull() ]['e']
                 #print("E",e)
                 PASSTHROUGH=True
                 ni=dfname.split("_n")[1].split("_ei")[0].replace("_",".")
                 ni=int(ni)
 
-                if len(e)<ni:
+                dfzeroe = df[ df['e'] <  1e-4]
+                if len(dfzeroe) > 0:
+                    print("$$$ $$$ IMPLANT")
+                    #print(df)
+                    #print(df[ df['e'] == 0 ])
+                    #sys.exit(0)
                     print("X... problem with number of points",len(e),"vs N=",ni)
                     IMPLANT=True
                     depth=df[ df['x'].notnull() ]['x']
                     #print("X",depth)
                     print("X... x data length==",len(depth) )
-            else:
+            elif len(df) > 0:# 'x' in df.keys() and len(x) > 0:
+                print("$$$ IMPLANT    ", len(df))
                 print("D... SETTING THE ENERGY TO fake ZERO BEGIN"   )
                 IMPLANT=True
                 df['e']=1e-6+0*df['x']
+                #print(df)
                 e=df['e']
                 depth=df[ df['x'].notnull() ]['x']
+            else:
+                print("S$$ BROKEN PASS and IMPLANT")
+                print(df)
+                sys.exit(0)
                 #print("XX",depth)
 
                 #print("X... SETTING THE ENERGY TO fake ZERO END"  , file=sys.stderr )
@@ -265,12 +289,14 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
                     centers = (0.5*(bins[1:]+bins[:-1]))
                     pars, cov = curve_fit(lambda x, mu, sig : norm.pdf(x, loc=mu, scale=sig), centers, n, p0=[e.mean(),e.std()])
                     print("D... energy  e ",pars )
+                    #print("________________________________________________")
                     #print("# use  -p help    for options")
                     print("   Emean {:9.5f}           sigma {:8.5f}  ".format(e.mean(),e.std()))
                     print("   E_FIT={:9.5f} {:8.5f}  sigma={:8.5f} {:6.5f}".format(
                         pars[0],  math.sqrt(cov[0,0]) ,
-                        e.std() , math.sqrt(cov[1,1]) ) )
+                        e.std() , math.sqrt(cov[1,1]) ) ) # FIT ...........
                     print("   Emin= {:9.5f}           Emax= {:8.5f}  ".format(e.min(),e.max()))
+                    # ------------- statistics end
                 if IMPLANT:
                     n, bins = np.histogram(depth,nbins, density=True)
                     centers = (0.5*(bins[1:]+bins[:-1]))
@@ -350,13 +376,30 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
 
             if graph=="x": #======= implantation plot
                 print("D... graphing  ",graph)
-                ax.hist( df['x'], 20, ec='k',alpha=0.3,label=dfname)
+
+                if max(df['x']) > 10000:
+                    xdivkov = 1000
+                    xunit = "mm"
+
+                ax.set_xlim(0, max(df['x']) / xdivkov)  # Set x-limits to determine graph size
+                n, bins, patches = ax.hist( df['x'] / xdivkov, 20, alpha=0.3,label=dfname, color=list(colors[0]) )
+                # Calculate bar width as 2% of x-axis size
+                xlim = ax.get_xlim()
+
+                FUN = True
+                if FUN:
+                    bar_width = 0.01 * (xlim[1] - xlim[0])  # 2% of the x-axis size
+                    ### Update the width of each bar
+                    for patch in patches:
+                        patch.set_width(bar_width)
+
+                colors=colors[1:] #  remove the first color
                 plotme=True
-                ax.set_xlabel("x implant [um]")
+                ax.set_xlabel(f"x implant [{xunit}]")
 
             if graph=="y": #======= implantation plot
                 print("D... graphing  ",graph)
-                ax.hist( df['y'], 20, ec='k',alpha=0.3,label=dfname)
+                ax.hist( df['y'], bins=20, ec='k',alpha=0.3,label=dfname)
                 plotme=True
                 ax.set_xlabel("y implant [um]")
 
@@ -454,6 +497,7 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
             #
             # i want to draw  Y: loss   X: total E
             #
+            # ----------------------------------------  dee-----START--
             if graph=="dee": #======= dE  vs  E
                 print("D... graphing  ",graph)
                 # de x e   , i need to know e
@@ -469,7 +513,7 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
                 #print("DEBUG ei ",ei,"  fw=", fw )
                 df['ei']=df['e']*0. + ei  # create DF ei to plot
                 df['de']=df['ei']-df['e']
-                print("D... DF E_i={} E_mean=={} dE_mean=={}  #N=={}".format(
+                print("$$$... DF E_i={:.3f} E_mean={:.3f} dE_mean={:.3f}  #N={}".format(
                                       df['ei'].mean(),df['e'].mean(),df['de'].mean(), ni   )
                 )
 
@@ -497,9 +541,10 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
 
 
                 plotme=True
+            # ----------------------------------------  dee-----END --
 
 
-            #=====view text data
+            # ------------------------------------  view -----  text data
             if (graph=="view") or (graph=="viewall"): #======= VIEW DATA
                 print("D... view:")
                 pd.set_option('display.max_colwidth', None)
@@ -516,9 +561,10 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
                 floatfwh=-1
 
 
-
             #========= fwhm>0
             #if floatfwh>=0.: #====== GENERATE GAUSS == fwhm=2.355sigma
+
+            # ------------------------------------  view -----  text data
             if graph=='e':
                 print("D... graphing classical E:  ", graph)
 
@@ -547,6 +593,9 @@ def main(Store="", graph="", printvar="all" ,randomize_yz=0., fwhm=0,  savefig="
                 #    ax.hist( df['x'], 20, ec='k',alpha=0.3,label=dfname+' [um]')
                 #    ax.set_xlabel("depth [um]")
                 #    plotme=True
+            # ************* END OF ALL GRAPH **********************
+            # ************* END OF ALL GRAPH **********************
+            # ************* END OF ALL GRAPH **********************
             #print("D... ================================== Graph SUBsection END", file=sys.stderr)
 
         ####################### FINALY SHOW PLOT
