@@ -599,10 +599,28 @@ def create_fire(*args, **kwargs):
     """
     This creates an isotope, use e.g. Ni56
     """
-    kwargs['return_object'] = False
+    kwargs['return_object'] = False # I force DEBUG this way
     create(*args, **kwargs)
+    return
+    # ======+++++++++++++++++++++ example how to create something:
+    kwargs['return_object'] = True # true mean real
+    print("abundances = {")
+    n = 0
+    for e in elements:
+        if e == "n":
+            continue
+        n+=1
+       # print( e)
+        x = create( e )
+        if len(x.abundances)>0:
+            for i in x.abundances:
+                print( f"'{e}{i[0]}' : {i[1]}, " )
+        #if n>10:break
+    print("} # abundances")
 
 
+
+# ===================================== USED BY CREATE_FIRE
 def create(*args, **kwargs ):
     """
     This creates an isotope, use e.g. Ni56
@@ -680,7 +698,7 @@ def create(*args, **kwargs ):
             else:
                 Zb=args[0].capitalize() # search index
                 A=0  # ?
-                print(" D..  rev. element:", Zb)
+                #print(" D..  rev. element:", Zb)
         try:
             Z=elements.index( Zb )
         except:
