@@ -26,8 +26,9 @@ def KREACT( op_amu,op_mex,ot_amu,ot_mex,oo_amu,oo_mex,oor_amu,oor_mex,
         quit()
     #print( "D... TKE=",TKE )
     #my (  $exctgt, $amu1, $amu2, $amu3, $amu4, $Q )=@_;
-#    print("D...op_mex ot_mex", op_mex, ot_mex ,  file=sys.stderr)
-#    print("D...op_amu ot_amu", op_amu, ot_amu ,  file=sys.stderr)
+    print("******************************************* using mass excess ")
+    print(f"   i...op_mex ot_mex:  {op_mex}     {ot_mex}  "  )
+    print(f"   i...op_amu ot_amu:  {op_amu}     {ot_amu}  "  )
 
     Q= op_mex+ot_mex - oo_mex - oor_mex # based on mex; notwrk4 e+e-
     Qamu=op_amu+ot_amu-oo_amu-oor_amu   # based on amu
@@ -40,20 +41,37 @@ def KREACT( op_amu,op_mex,ot_amu,ot_mex,oo_amu,oo_mex,oor_amu,oor_mex,
         print("--- {:3.1f} deg  TKE={:6.3f} MeV Q={:6.3f} MeV ------------".format(theta,TKE,Q/1000. ) ,
               file=sys.stderr )
     #rs;
+    amu_unit = 931.49403
     m1=op_amu* 931.49403
     m2=ot_amu* 931.49403
-    #print("D... m1 m2:", m1,m2)
+
     m3=oo_amu* 931.49403
     m4=oor_amu* 931.49403
+
+    print(f"   i...     m1 m2: {m1}         {m2}  ")
+    print(f"   i...     m3 m4: {m3}         {m4}  ")
+    Etot_proj = TKE + m1
+    gamma_proj = Etot_proj / m1
+    beta_proj = sqrt(1 - 1 / gamma_proj**2)
+
+    print(f"             proj.. TKE   proj: {TKE}           ")
+    print(f"             proj.. TKE   proj: {TKE/op_amu} MeV/u          ")
+    print(f"             proj.. Etot  proj: {Etot_proj}           ")
+    print(f"             proj.. gamma proj: {gamma_proj}           ")
+    print(f"             proj.. beta  proj: {beta_proj}           ")
+
     t=TKE  # projectile energy
     # adding excitation of target later
 
     if _DEBUG==1:
         print("DEBUG...   AMUs (nudat): %f %f %f %f" % (m1,m2,m3,m4) ,
               file=sys.stderr)
-    es=t + m1  + m2;
+
+    es=t + m1 + m2;
+
     ##### JAROCMS p1 good; E1 ^2=(t + m1)**2  ####
     p1=sqrt(     (t + m1)**2  - m1**2  )
+
     ######### JAROCMS Ecms  from invariant # p3cform= sum p^2/2m
     Ecms2= (t + m1)**2   +  m2**2  + 2*(t + m1)*m2 - p1**2
     Ecms=sqrt( Ecms2 )
@@ -102,6 +120,7 @@ def KREACT( op_amu,op_mex,ot_amu,ot_mex,oo_amu,oo_mex,oor_amu,oor_mex,
     # prepare 2-solution's --- decision......
     E1=t+m1 # full energy
     V=p1/( E1 + m2 ) # CMS velocity  pc/E->v/c?
+    beta_cms =V;
     ttr=- ( m1 + m2)/ m2 * Q
     if (Q>0):
         ttr=0
@@ -346,7 +365,8 @@ def KREACT( op_amu,op_mex,ot_amu,ot_mex,oo_amu,oo_mex,oor_amu,oor_mex,
 
         print("        p1   =%15.5f (projectile momentum)" %  p1 )
         #print("        E1   =%15.5f (projectile - total energy)" % E1 )
-        print("        V    =%15.5f (velocity of CMS ... v/c)" % V )
+        print("    beta_cms =%15.5f (velocity of CMS ... v/c)" % V )
+        print(f"   gamma_cms ={1. / sqrt(1 - V * V):15.5f} " )
         print("        ttr  ={:15.5f} (Threshold in Lab)".format(ttr) )
         print("        ttrc ={:15.5f} (Threshold in CMS == -Q)".format(ttrc) )
         print("        Q    ={:15.5f} (if Q>0 = exoterm  [MeV])".format(Q) )
