@@ -13,11 +13,9 @@ from nuphy2.prj_utils import fail
 from nuphy2.prj_utils import Bcolors
 from nuphy2.prj_utils import super_print
 
-
 import nuphy2.isotope as isotope
 # import nuphy2.rolfs as rolfs # Coul barrier here
 
-
 #-------------------- from nuphy---------------------
 import os
 import tempfile   # create tempdir
@@ -33,14 +31,9 @@ from nuphy2.isotope import gaseous,densities,elements,molarweights
 # # import nuphy2.isotope as isotope
 import nuphy2.compounds as srcomp
 
-
 import threading
 import time
 
-
-
-
-
 ################################  SR
 # i need interpolation now.... #
 #https://docs.scipy.org/doc/scipy/reference/tutorial/interpolate.html
@@ -53,9 +46,14 @@ import scipy.integrate as integrate
 
 import pandas as pd
 
-
 import re
 
+T_STP = 273.15
+T_NTP = 293.15
+# ---------------- global definition
+P_BASE = 101_325
+T_BASE = T_NTP
+
 TRIMAUTO="""1
 
 TRIMAUTO allows the running of TRIM in batch mode (without any keyboard inputs).
@@ -309,12 +307,13 @@ def srinterpolate( eneloss , plot=False):
 
 
 
-def get_sr_loss( SRIN , Emax=5.8, dmax=10 , unit="um" ):
-    print("\ni... --------running---- SR.EXE LOSS: Eini={}  t={:.3f} {}".format(Emax, dmax, unit) )
+def get_sr_loss( SRIN , Emax=5.8, dmax=10 , unit="um", silent=True):
     if SRIN=="":
-        print("XXX...   SR.IN was not created, returns")
+        print("X...       SR.IN was not created, get_sr_loss() returns")
         return
-    eneloss,kevum,mevmg=run_sr_exe( SRIN )  # This returns loss tables BUT ALSO COEF!
+    print("\ni... --------running---- SR.EXE LOSS: Eini={}  t={:.3f} {}".format(Emax, dmax, unit) )
+    #
+    eneloss,kevum,mevmg=run_sr_exe( SRIN, silent=silent)  # This returns loss tables BUT ALSO COEF!
     eneloss2=eneloss
     if unit=="um":
         for k in eneloss.keys():
@@ -448,7 +447,9 @@ def CheckSrimFiles():
     #      1347344  MSVBVM50.DLL
     #       212240  RICHTX32.OCX
     #       224016  TABCTL32.OCX
-
+    #
+    #  and later  617896  comctl32.ocx
+    #
     # If you find the file libs2013.tgz - try:
     # find ~/.local/lib -iname "libs*.tgz"
 
@@ -492,6 +493,10 @@ def CheckSrimFiles():
         print("X... srim not found in ",paths)
         print(helpsrim)
         fail("X... install SRIM first")
+        CMD =  "sriminst.sh"
+        output = subprocess.check_output(CMD,
+                   stderr=subprocess.DEVNULL)
+
     return RPATH
 
 
@@ -947,7 +952,7 @@ def targ(  name, thick,   ion,  outerdens  , SRLINE ):
 
         #print(OUTTEXT)
         #quit()
-        print("DDD... returns compoud, no SRIN")
+        print("i...  compoud is returned, I cannt do SR.IN now")
         while len(SRLINE)>0:
             SRLINE.pop(0)###### I cannot create SR.IN for compounds now.....
         return OUTTEXT  #################################################### COMPOUND RETURN HERE
@@ -1130,10 +1135,10 @@ def srim_readout_range(temppath):
             ###print( 'LINEREM=',cont[0].decode('ascii', errors='ignore') )
         while cont[0].decode('utf8', errors='ignore').find('Number')<0 or cont[0].decode('utf8', errors='ignore').find('Angstrom')<0:
             cont.pop(0)
-        print( 'LINEREM=',cont[0].decode('utf8', errors='ignore') )
+        #print( 'LINEREM=',cont[0].decode('utf8', errors='ignore') ) # removing this line  Number    (Angstrom) (Angstrom)  (Angstrom)
         cont.pop(0)
         cont.pop(0)
-        print( 'LINE=',cont[0].decode('utf8', errors='ignore') )
+        #print( 'LINE=',cont[0].decode('utf8', errors='ignore') ) # good line ?
         return [x.decode('utf8', errors='ignore').rstrip() for x in cont]
 
 
@@ -1151,7 +1156,7 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
         quit()
     ############## CREATE TEMP #####################
     temppath = tempfile.mkdtemp( prefix='srim_')+'/'
-    if not silent: print('X... copying from',RPATH,'to',temppath)
+    if not silent: print('I... copying from',RPATH,'to',temppath)
     copy_tree( RPATH , temppath )
 #    os.chdir(temppath)
     #print('D...', glob.glob("TRIM.exe")  )
@@ -1313,12 +1318,12 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
 
 
 
-    print("######### len df {}   vs  nmax {}  vs removed {}".format( len(df),  nmax, remvd ) )
+    print(f"D...  len TRANSMIT {len(df)}   vs  nmax {nmax}  vs removed {remvd}")
     dfr = DataFrame({}, columns=['x','y','z'])
     # RANGE_3D
     # if len(df)<1 or  df['e'].mean is None:
     if len(df)+remvd<nmax or  df['e'].mean is None:
-        print("!... no transmited ions probably, i should check RANGE_3D.TXT")
+        print("!... no transmited ions:  i go to check RANGE_3D.TXT ... ")
         data=srim_readout_range( temppath )
         print('D... data read LEN=', len(data))
         datas=[ (x.split()[1:]) for x in data ]
@@ -1330,12 +1335,14 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
         #print( df.iloc[-5:][['e','x','y','z','cosx','cosy'] ] )
         #df.drop('i', axis=1, inplace=True)
         #df.drop('n', axis=1, inplace=True)
-        print("i... DEPTH= ",dfr['x'].mean(),'um +- ',dfr['x'].std())
+        # I WILL ANNOUNCE LATER *************************************************** LATER
+        #print("i... DEPTH= ",dfr['x'].mean(),'um +- ',dfr['x'].std())
 
         print("### Total events: {} = {} pass  + {} range ".format(nmax, len(df), len(dfr) ) )
     ###########################  DELETE TEMP #########
-    if not silent:print('x... deleting temporary', temppath)
+    #if not silent:print('x... deleting temporary', temppath)
     #shutil.rmtree(temppath)
+    #              df and df with range
     return df,dfr
 
 
@@ -1445,7 +1452,8 @@ def isitGas( material ):
 # get_thick_rho  ......  I extract the part
 #         return   thick [ug/cm2] and rho g/cm3
 #####################################
-def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #convert properly um and find rho
+#def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #convert properly um and find rho
+def get_thick_rho( material,  thick, rho ,Pressure=P_BASE, Temperature=T_BASE):   #convert properly um and find rho
     """
     takes all thicknesses   um  ug:
 
@@ -1462,7 +1470,7 @@ def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #
     mm_amu=0.0
     #print("i... @ get_thick_rho start")
     # i need rho(maybe; amu(for rrate)
-    print("*** ***")
+    print("*** *** *** ***  get_thick_rho() ")
     rho1,mm_amu,isotope=material_density(material) # compound/element/isot = ALL
     if rho==0:
         rho=rho1
@@ -1478,22 +1486,25 @@ def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #
     if material.title() in srcomp.material_gas:
         """
         trim assumes the target as STP before 1982
-        T=273.15 K
+        T=273.15 K     I say T_BASE willl be T_STP or T_NTP
         p=101.325 kPa           =>>>>     p=101.325 kPa   10^5 !!!!!
         SRIMHelp/helpTR23.rtf
         """
-        R=101.325e+3/273.15/rho
+        #R=101.325e+3/T_BASE/rho
+        #print("*** * * * * * * * * * * * * *")
+        R=P_BASE/T_BASE/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
+        #print(P_BASE, T_BASE, rho, Pressure, Temperature)
+        print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} NEW now={rho2:.7f}  (comp)')
     elif material.title() in elements:
         #print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ={:d}".format(eZ))
         #print(gas)
         if gas[ eZ ]==1:
-            R=101.325e+3/273.15/rho
+            R=P_BASE/T_BASE/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
+            print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} NEW now= {rho2:.7f}  (elem)')
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         if isotope is None:
@@ -1509,9 +1520,9 @@ def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #
             eZ=isotope.Z
             if gas[ eZ ]==1:
                 print('i... GAS')
-                R=101.325e+3/273.15/rho
+                R=P_BASE/T_BASE/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
+                print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} NEW now={rho2:.7f}  (isotope)')
     rho=rho2
     #print("D... rho WAS deduced")
     # THICKNESS TO mgcm2:    ##### MY UNIT WILL BE mg/cm2
@@ -1562,7 +1573,8 @@ def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #
 #
 #            prasarna  ......... incomming0
 ########################################
-def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=101325, Temperature=273):
+#def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=101325, Temperature=273):
+def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=P_BASE, Temperature=T_BASE, silent=False):
     '''
     Here I prepare materials:  single layers
     '''
@@ -1581,22 +1593,23 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
     #print("DDD .... items of material_gas", srcomp.material_gas ) #"Air" only
     if material in srcomp.material_gas:
         """
-        trim assumes the target as STP before 1982
+        trim assumes the target as STP before 1982 ... not sure, the air density shows values pV=nRT for 293K???
         T=273.15 K
         p=101.325 kPa
         SRIMHelp/helpTR23.rtf
         """
-        R=101.325e+3/273.15/rho
+        R=P_BASE/T_BASE/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
+        #print("...   P T  rho Pr Te:", P_BASE, T_BASE, rho, Pressure, Temperature)
+        print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} NEW now={rho2:.7f}   (trimin-comp)')
     elif material.title() in elements:
         print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ=",eZ)
         if gaseous[ eZ ]==1:
-            R=101.325e+3/273.15/rho
+            R=P_BASE/T_BASE/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
+            print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} now={rho2:.7f}  (trimin-elm)')
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         try:
@@ -1609,9 +1622,9 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
             eZ=isotope.Z
             if gaseous[ eZ ]==1:
                 print('i... GAS')
-                R=101.325e+3/273.15/rho
+                R=P_BASE/T_BASE/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
+                print(f'i...rho at STD (0deg,101.3kPa)={rho:.7f} now={rho2:.7f} (trimin isot)')
     rho=rho2
 
     #print("DDD... rho deduced")============================================
@@ -1624,12 +1637,12 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
         thick=float( thick.split('mg')[0] )
         thickok=True
     elif thick.find('um')>0:
-        print('i...  thickness in [um] ==> I use rho=',rho)
+        print(f'i...  thickness in [um] ==> I use rho={rho:.7f}')
         thick=float(thick.split('um')[0])
         thick=get_mgcm2( thick,  rho ) # um in, mgcm2 out
         thickok=True
     elif thick.find('mm')>0:
-        print('i... thickness in [mm] ==> I use rho=',rho)
+        print(f'i... thickness in [mm] ==> I use rho={rho:.7f}')
         thick=float(thick.split('mm')[0])
         thick=get_mgcm2( thick*1000,  rho ) # um in, mgcm2 out
         thickok=True
@@ -1638,17 +1651,22 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
         quit()
     # INFO:
     print( "DDD... rho=",rho )
-    print('i... {} thickness {:.6f} mg/cm2 for rho={:.3f} ... {:.0f} A = {:.2f}um'.format( material, thick,
-                                                rho,1000*thick/rho/1e-2  ,   1000*thick/rho/1e+2 ) )
+    print('i... {} thickness {:.6f} mg/cm2 for rho={:.7f} ...  {:.2f}um'.format(
+        material,
+        thick,
+        rho,
+#        1000*thick/rho/1e-2  ,
+        1000*thick/rho/1e+2 ) )
 
     # AT THIN MOMENT I HAVE A GOOD rho an thick in mgcm2
 
     #print('DDD... goto PrepSrimFile')
     TRIMIN,SRIN=PrepSrimFile( ion=incomming0, energy=Eini, angle=0., number=number,
                             mater=material, thick=thick, dens=rho  )
-    print('DDD... after PrepSrimFile',Eini, thick)
-    print("D... SRIN==",SRIN)
-    get_sr_loss( SRIN , Eini, thick , unit="mg")
+    #print('DDD ... after PrepSrimFile',Eini, thick)
+    #print("DDD ... SRIN==",SRIN)
+    #print("********************************")
+    get_sr_loss( SRIN , Eini, thick , unit="mg", silent=silent) # if no SRIN... then wnat?
 
     return TRIMIN
 ############# END OF PREPARE TRIMIN
@@ -1656,10 +1674,10 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
 
 #--------------------------------------------------- START OF OLD NUPHY BIN
 def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness="0ug",
-                  material="c12", Pressure=101.325e+3, Temperature=273.15,
+                  material="c12", Pressure=P_BASE, Temperature=T_BASE,
                   silent = False, fwhm=0, Store="" ):
 
-    #print("1=============/{}/==========".format(Store))
+    #print("1=============/{}/==========".format(Store)) # writeh5
     ipath=CheckSrimFiles()
     if ipath is None:
         fail("X... SRIM not found ")
@@ -1682,8 +1700,8 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
     #print("DDD... ", material)
     nmats=len(material.split(','))
     print("D... counting number of layers",nmats)
+    # rho is default 0 .... but LIST=> commaseparated STR from HERE
     if nmats>1:
-
         print('!... ',nmats,'materials - TEST REGIME:', thick.split(","))
         if nmats!=len(thick.split(',')):
             print('!... NOT THE SAME NUMBER OF THICKNESSES')
@@ -1696,13 +1714,16 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
                 rho=','.join( map(str,[0]*nmats) )
         print('i... PREPARING ANALYSIS  mat, thick, rho for:', nmats,"materials",material,".")
         TRILIST=[]
+        # now work with rho commaseparated for different layers
+        # --------------------------------------- BEGIN --------------@@@
         for imat in range(nmats):
             print(imat,'... =========', material.split(',')[imat], thick.split(',')[imat],  rho.split(',')[imat]
                   , incomming0 , Eini , 0 , number
                   ,    "================================"  )
             #TRIMIN=main.prepare_trimin(  material, thick,  rho  , incomming0  , Eini, 0, number) # prasarna incomming0
 
-            TRILIST.append( prepare_trimin(  material.split(',')[imat], thick.split(',')[imat],  rho.split(',')[imat] , incomming0 , Eini , 0 , number  , Pressure=Pressure, Temperature=Temperature)  )
+            TRILIST.append( prepare_trimin(  material.split(',')[imat], thick.split(',')[imat],  rho.split(',')[imat] , incomming0 , Eini , 0 , number  , Pressure=Pressure, Temperature=Temperature, silent=silent)  )
+        # --------------------------------------------- END -------@@@
         print('i... I GOT ALL TRIM.IN files. Now somebody must merge....')
         ############################   MERGING  LAYERS ##############
         print('D--------------')
@@ -1715,7 +1736,8 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
         TRIMIN= TRIMIN + TRILIST[0].split("\n")[4].rstrip()+'\r\n'
         TRIMIN= TRIMIN + TRILIST[0].split("\n")[5].rstrip()+'\r\n'
         TRIMIN= TRIMIN + TRILIST[0].split("\n")[6].rstrip()+'\r\n'
-        TRIMIN= TRIMIN + TRILIST[0].split("\n")[7].rstrip()+'\r\n'   # target material  num ele and layers
+        TRIMIN= TRIMIN + TRILIST[0].split("\n")[7].rstrip()+'\r\n'
+        # target material  num ele and layers
         #TRIMIN=TRIMIN+"            8 \r\n"
 
 
@@ -1729,6 +1751,7 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
         TRILISTTOT=[] # totallist for Atom
         lineLay=[]    # Layer Layer long line
         layerList=[]
+        # -------------------------------- BEGIN @@@@@@
         for imat in range(nmats):
             listOfLines=TRILIST[imat].split('\n')
             if listOfLines[7].find('Target material')<0:
@@ -1745,6 +1768,7 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
                 if v.find('Layer')>=0 and v.find('Density')>0:
                     print(imat,'LAYER LINE= #',j+2+1) # starts with 0
                     layerList.append( re.findall(r'".+"|[\w\.\-]+', listOfLines[j+2] ) )
+        # -------------------------------- END @@@@@@
         #print(line8)
         layname='...'.join( [ i[0].strip("\"").rstrip() for i in line8]  )
         layname='"'+layname+'"'
@@ -1879,8 +1903,12 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
         #quit()
 
     else:
-        print("D... one material (not layers) - preparing TRIMIN")
-        TRIMIN=prepare_trimin(  material, thick,  rho  , incomming0  , Eini, 0, number, Pressure=Pressure, Temperature=Temperature) # prasarna incomming0
+        print("i... one material (not layers) - preparing TRIMIN")
+        TRIMIN=prepare_trimin(  material, thick,  rho  , incomming0  ,
+                                Eini, 0,
+                                number,
+                                Pressure=Pressure, Temperature=Temperature,
+                                silent=silent) # prasarna incomming0
         #  angle==0
     #########################################
     # PREPARE FILE
@@ -1891,7 +1919,7 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
 
 
 
-    print("D... -----------------------------------------------------running",rho,type(rho))
+    #print("i... ----running rho=",rho,type(rho)) #  rho==0 if compound??
     # RUN ############################
     if silent:
         tmpp,tmppr=run_srim(ipath, TRIMIN,  silent=True, nmax=number)
@@ -1902,13 +1930,12 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
 
     # i am adding an artifitial Eini = 0
     tmpp['eini']=tmpp['x']*0.0 +  Eini
-    print(tmpp[-5:])
     #
     # tmpp ========= DATAFRAME FROM SRIM
     #
     IMPLANT = False
     PASSTHR = False
-    if 'e' in tmpp:
+    if 'e' in tmpp and len(tmpp) > 0: # 'e' is it is always IN
         PASSTHR = True
         if fwhm!=0.:  # convolute wit FWHM at Eini level ##### save -f
             print("i... fwhm applied to E")
@@ -1920,17 +1947,27 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
         #    sigma= ( sigma*sigma + (float(fwhm)/2.355)**2 )**0.5
         mean=tmpp['e'].mean()
         median=tmpp['e'].median()
-        #print()
-        print( "{:.3f} MeV (median {:.3f}) +- {:.3f}  hi-lo={:.3f}  Eloss={:.3} MeV ({} events)".format( mean, median,  sigma , deint ,  Eini-mean, len(tmpp))   )
+        print(tmpp[-5:]) # MAIN OUTPUT  TRANSMITTED
+        print()
+        print( "{:.3f} MeV (median {:.3f}) +- {:.3f}  hi-lo={:.3f}  Eloss={:.3} MeV ({} events)".format( mean, median, sigma, deint, Eini-mean, len(tmpp)) )
 
     #else:
     if len(tmppr)>0:
         IMPLANT=True
         tmppr['eini']=tmppr['x']*0.0 +  Eini
-        print(tmppr[-5:])
         #print(tmpp)
         #print()
-        print('{:.3f} +- {:.4f} um implanted depth ({} events)'.format( tmppr['x'].mean(), tmppr['x'].std(),len(tmppr) )  )
+        print(tmppr[-5:])  # MAIN OUTPUT RANGE3D
+        #
+        output_unit = 'um'
+        divko = 1
+        if tmppr['x'].mean() > 10_000:
+            output_unit = 'mm'
+            divko = 1000
+        print('{:.3f} +- {:.4f} {} implanted depth ({} events)'.format( tmppr['x'].mean() / divko,
+                                                                        tmppr['x'].std() / divko,
+                                                                        output_unit,
+                                                                        len(tmppr) )  )
         mean=0.0
         median=0.0
         deint=0.0
@@ -1942,32 +1979,68 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
     #   print(tmpp['e'].mean(), '  ' ,tmpp['e'].std() )
 
 
+    print(f" IMPLANT {IMPLANT}, PASSTHR {PASSTHR}")
     if IMPLANT and PASSTHR:
+        print("i... combining implant and passthrough")
         tmpp = pd.concat([tmpp,tmppr], axis=0, ignore_index=True)
+    elif IMPLANT:
+        tmpp = tmppr
         #print(tmpp)
 
     ### MAYBE - I WILL NUMBER ALREADY FROM HERE
-    if Store!="":
+    if Store!="":  # writeh5
 
         store = pd.HDFStore( Store )
         existing=len(store.keys())
-        print('D... already existing is', existing )
+        store.close()
+
+        print('D... already existing keys: ', existing )
+
         #print(store)
-        if material.title() in srcomp.material_gas:
-            pt='P{}_T{}'.format( Pressure, Temperature )
-        else:
-            pt=""
-        print( "D... args=",fwhm )
+        #print(" MAT ****************************", material.title()   )
+        # WHY THE HACK   TITLE????
+        #if material.title() in srcomp.material_gas:
+        pt=""
+        for ima in material.split(","):
+            if ima.lower() in srcomp.material_gas:
+                pt='P{}_T{}'.format( Pressure, Temperature )
+        #print( "D... args=",fwhm )
         #  rho instead of density === can be a problem :  0,0
         WRmat=material.lower().replace(",","_")
         WRthi= thickness.replace(",","_")
+        # howto get rho from compound????
+        #print("+++++", rho)
         WRrho=str(rho).replace(",","_")
+        #print("+++++", WRrho)
 
-        fname='srim{:03d}_{}_in_{:_<6s}_t{:_<6s}_r{}_pt{}_n{:04d}_ei{:06.3f}_ef{:06.3f}_sf{:06.4f}_f{:0.4f}'.format( existing,incomming, WRmat, WRthi, WRrho,pt, int(number), float(energy), mean, sigma, float(fwhm)    )
-        print( "D...  file=",fname )
+        # I removed pt{} and left {}
+        # I fill ____ to keep alignement  _<6 .........
+        fname='srim{:03d}_{}_in_{:_<6s}_t{:_<6s}_r{}_{}_n{:04d}_ei{:06.3f}_ef{:06.3f}_sf{:06.4f}_f{:0.4f}'.format(
+            existing, # serialnumber
+            incomming, # h1
+            WRmat, WRthi,  # mylar, 120um
+            WRrho, # DENSITY only if in argument else 0
+            pt, #  ptP...T...
+            int(number), # 9999
+            float(energy), # keV
+            mean, # keV
+            sigma, # straggling ~0.1keV
+            float(fwhm) # FWHM??? artificially already into simulation?
+        )
+        #
+        print("i... TAGName:\n",fname )
+        print()
         fname=fname.replace('.','_')
-        store[fname] = tmpp
-        print(store)
+
+        # shorter time when parallel
+        store = pd.HDFStore( Store )
+        if len(tmpp) > 0:
+            store[fname] = tmpp # DF TRANSMIT + RANGE combined ABOVE concat
+            #elif len(tmppr) > 0:
+            #    store[fname] = tmppr # DF RANGE
+        else:
+            print("X... DF NULL!!!!", tmpp)
+        #print(store)
         store.close()
 
 # RUN SRIM ENDED
@@ -1990,9 +2063,10 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
 def main( i="", m="" , t="", e="", a="",  n=100,
           dens=0,              # override density
           f=0,                 # fwhm of the detector
-          p=101325, k=273.15, #k =temp in K
+          pressure=P_BASE,
+          kelvin=T_BASE, #k =temp in K was 273.15
 #          h="",                #
-          w="",
+          writeh5="",
           s = False,           # silent
           debug=False,
           ):
@@ -2037,9 +2111,9 @@ def main( i="", m="" , t="", e="", a="",  n=100,
         # if f == "": fail(Bcolors.WARNING+"?... give me value,outfile      -f t3a  -f t3a,a.txt" + Bcolors.ENDC )
         # -S a,T3 ... save to textfile the value
 
-        if isinstance(w,bool): fail(Bcolors.WARNING+"? -w filename.h5 is expected")
+        if isinstance(writeh5,bool): fail(Bcolors.WARNING+"? -w filename.h5 is expected")
 
-        if w=="": print(Bcolors.WARNING+"i... not saving.... -w filename.h5" + Bcolors.ENDC)
+        if writeh5=="": print(Bcolors.WARNING+"i... not saving.... -w filename.h5" + Bcolors.ENDC)
         #
         #
         print(Bcolors.OKGREEN + "D... PROJECTILE   :", i + Bcolors.ENDC )
@@ -2052,7 +2126,7 @@ def main( i="", m="" , t="", e="", a="",  n=100,
 
 
 
-        print( Bcolors.OKGREEN +  "i... to run without SRIM screen:  -s" + Bcolors.ENDC)
+        print( Bcolors.OKGREEN +  "i... to run without SRIM GUI screen:  -s" + Bcolors.ENDC)
         # print( Bcolors.OKGREEN +  "D... OUTGOING 1   :" , m+ Bcolors.ENDC)
         #nu3.pprint()
 
@@ -2060,13 +2134,14 @@ def main( i="", m="" , t="", e="", a="",  n=100,
         # print( Bcolors.BOLD +  "D... Excitation  =:", x,"MeV"+ Bcolors.ENDC )
         #  print( Bcolors.BOLD +  "D... Outputfile,V=:", "None"+ Bcolors.ENDC )
         print("\n")
+        #print("... zmatek before old *******  T ", kelvin)
         old_nuphy_bin(incomming=i, energy=e, number=n,
                       density=dens,
                       thickness=t,
-                      material=m, Pressure=p, Temperature=k,
+                      material=m, Pressure=pressure, Temperature=kelvin,
                       silent = s,
                       fwhm=f,
-                      Store=w )
+                      Store=writeh5 )
 
 
         # h1 = isotope.create(i)  # incomming ion
